@@ -11,10 +11,6 @@
 #include <qregexp.h>
 #include <qstringlist.h>
 #include <klocale.h>
-#include <dom/html_document.h>
-#include <dom/html_element.h>
-#include <dom/html_table.h>
-#include <dom/dom_text.h>
 
 #include "datinfo.h"
 #include "datmanager.h"
@@ -45,34 +41,40 @@ DatInfo::DatInfo( const KURL& url ) : m_access ( 0 ), m_access2( 0 )
 
     /* get the pointer of Thread class */
     m_thread = Kita::Thread::getByURLNew( m_datURL );
-    if( m_thread == NULL ){
+    if ( m_thread == NULL ) {
 
-	/* create Thread */
-	m_thread = Kita::Thread::getByURL( m_datURL );
-	if( m_thread == NULL ) return;
-	
-	/* read idx file */
-	ThreadIndex::loadIndex( m_thread, m_datURL );
+        /* create Thread */
+        m_thread = Kita::Thread::getByURL( m_datURL );
+        if ( m_thread == NULL ) return ;
+
+        /* read idx file */
+        ThreadIndex::loadIndex( m_thread, m_datURL );
     }
 
     m_thread = Thread::getByURL( m_datURL );
-    
+
     /* japanese strings */
+#if KDE_IS_VERSION( 3, 3, 0 )
+    m_spacestr = Kita::utf8ToUnicode( KITAUTF8_ZENSPACE );
+#else
     m_spacestr = ". ";
+#endif
     m_framestr1 = Kita::utf8ToUnicode( KITAUTF8_FRAME1 ); /* |  */
     m_framestr2 = Kita::utf8ToUnicode( KITAUTF8_FRAME2 ); /* |- */
     m_framestr3 = Kita::utf8ToUnicode( KITAUTF8_FRAME3 ); /* L  */
 
     /* make directory */
     QString cacheDir = Cache::baseDir() + Cache::serverDir( m_datURL ) + Cache::boardDir( m_datURL );
-    if( !Kita::mkdir( cacheDir ) ) return;
-    
-    initPrivate();
+    if ( !Kita::mkdir( cacheDir ) ) return ;
+
+    initPrivate(
+        TRUE /* load cache */
+    );
 }
 
 DatInfo::~DatInfo()
 {
-    deleteAccessJob();
+    initPrivate( FALSE );
 }
 
 
@@ -82,7 +84,7 @@ void DatInfo::init()
 {
     QMutexLocker locker( &m_mutex );
 
-    return initPrivate();
+    return initPrivate( TRUE );
 }
 
 /* public */
@@ -94,20 +96,15 @@ void DatInfo::wait()
 /* Init. If loadCache = TRUE, load data from cache. */ /* private */
 void DatInfo::initPrivate( bool loadCache )
 {
-
     /* stop & delete dat loader */
     deleteAccessJob();
 
     /* init variables */
-    m_rawData = QString::null;
     m_broken = FALSE;
     m_lock = 0;
     m_nowLoading = FALSE;
     m_lastLine = QString::null;
 
-    /* reset readNum  */
-    m_thread->setReadNum( 0 ); 
-    
     /* clear ResDatVec */
     m_resDatVec.clear();
     increaseResDatVec( RESDAT_DEFAULTSIZE );
@@ -122,29 +119,31 @@ void DatInfo::initPrivate( bool loadCache )
              SLOT( slotReceiveData( const QStringList& ) ) );
     connect( m_access, SIGNAL( finishLoad() ), SLOT( slotFinishLoad() ) );
 
-    if( !loadCache ) return;
-    
-    /* get dat from cahce   */
+    if ( !loadCache ) return ;
+
+    /* reset ReadNum before loading cache. */
+    /* ReadNum & subject are updated by Access::getcache() */
+    m_thread->setReadNum( 0 );
+
+    /* get dat from cahce  */
     /* slotReceiveData() is called from Access::getcache() */
     m_access->getcache();
 
-    /* save thread information */
-    if( m_thread->readNum() ) ThreadIndex::saveIndex( m_thread, m_datURL );
+    /* save up-to-date thread information */
+    ThreadIndex::saveIndex( m_thread, m_datURL );
 }
 
 
 /* private */
 void DatInfo::resetResDat( RESDAT& resdat )
 {
-
-    resdat.set = FALSE;
+    resdat.num = 0;
     resdat.parsed = FALSE;
     resdat.broken = FALSE;
-    resdat.setAnclist = FALSE;
     resdat.anclist.clear();
     resdat.checkAbone = FALSE;
     resdat.abone = FALSE;
-    resdat.marked = FALSE;
+    resdat.isResponsed = FALSE;
 }
 
 
@@ -173,39 +172,6 @@ void DatInfo::deleteAccessJob()
     }
 }
 
-
-/* copy one line to resdat.            */ /* private */
-bool DatInfo::copyOneLineToResDat( const QString& line, int num )
-{
-
-    if ( num <= 0 ) return FALSE;
-    if ( line == QString::null ) return FALSE;
-
-    /* If resdat vector is short, then resize the vector. */
-    while ( ( int ) m_resDatVec.size() <= num ) increaseResDatVec( RESDAT_DELTA );
-
-    /* reset and  set new data */
-    RESDAT& resdat = m_resDatVec[ num ];
-    resetResDat( resdat );
-
-    resdat.set = TRUE;
-    resdat.linestr = line;
-    if ( m_thread->readNum() < num ) m_thread->setReadNum( num );
-	
-    m_rawData += line + '\n';
-
-    if ( num == 1 ) parseDat ( num ); /* to get subject */
-
-    /* is this dat file broken ? */
-    if ( line.contains( "<>" ) != 4 ) {
-        resdat.broken = TRUE;
-        m_broken = TRUE;
-    }
-
-    return TRUE;
-}
-
-
 /* public */
 const KURL& DatInfo::url()
 {
@@ -241,7 +207,7 @@ bool DatInfo::updateCache( const QObject* parent )
 
     connect( this, SIGNAL( finishLoad() ),
              parent, SLOT( slotFinishLoad() ) );
-    
+
     m_access->getupdate( m_thread->readNum() );
 
     return TRUE;
@@ -261,28 +227,78 @@ void DatInfo::slotReceiveData( const QStringList& lineList )
 
     /* copy lines to buffer */
     int count = lineList.count();
-    for ( int i = 0; i < count ; ++i ) copyOneLineToResDat( lineList[ i ], m_thread->readNum() +1 );
+    for ( int i = 0; i < count ; ++i ) copyOneLineToResDat( lineList[ i ] );
 
     emit receiveData();
 }
 
 
+/* copy one line to resdat.
+   See also DatInfo::slotReceiveData()   */ /* private */
+bool DatInfo::copyOneLineToResDat( const QString& line )
+{
+    if ( line == QString::null ) return FALSE;
+
+    /* update ReadNum */
+    const int num = m_thread->readNum() + 1;
+    m_thread->setReadNum( num );
+
+    /* If resdat vector is short, then resize the vector. */
+    while ( ( int ) m_resDatVec.size() <= num ) increaseResDatVec( RESDAT_DELTA );
+
+    /* reset ResDat */
+    RESDAT& resdat = m_resDatVec[ num ];
+    resetResDat( resdat );
+
+    resdat.num = num;
+    resdat.linestr = line;
+
+    /* get subject */
+    if ( num == 1 ) parseDat( num );
+
+    /* search all responses which are responsed by this line. */
+    if ( KitaConfig::checkResponsed() ) {
+
+        if ( parseDat( num ) && !checkAbonePrivate( num ) ) { /* parse line here to get AncList */
+
+            const int maxRange = 10;
+
+            AncList& anclist = m_resDatVec[ num ].anclist;
+            for ( AncList::iterator it = anclist.begin(); it != anclist.end(); ++it ) {
+
+                int fromNum = ( *it ).from;
+                int toNum = QMIN( num - 1, ( *it ).to );
+                if ( toNum - fromNum + 1 > maxRange ) continue;
+
+                for ( int i = fromNum; i <= toNum; ++i ) {
+
+                    if ( !checkAbonePrivate( i ) ) m_resDatVec[ i ].isResponsed = TRUE;
+                }
+            }
+        }
+    }
+
+    return TRUE;
+}
+
+
 /* slot called when Kita::Access
    finished loading new dat */      /* private  slot */
 void DatInfo::slotFinishLoad()
 {
     /* save thread information */
     ThreadIndex::saveIndex( m_thread, m_datURL );
-    
-    if ( m_thread->readNum() == 0 && m_access2 == NULL && BoardManager::type( m_datURL ) == Board_2ch ) {
+
+    /* re-try by offlaw.cgi */
+    if ( m_thread->readNum() == 0 && m_access2 == NULL && DatManager::is2chThread( m_datURL ) ) {
         if ( Account::isLogged() ) {
-            initPrivate();
+            initPrivate( TRUE );
             m_access2 = new OfflawAccess( m_datURL );
-            connect( m_access2, SIGNAL( receiveData( const QString& ) ),
-                      SLOT( slotReceiveData( const QString& ) ) );
+            connect( m_access2, SIGNAL( receiveData( const QStringList& ) ),
+                     SLOT( slotReceiveData( const QStringList& ) ) );
             connect( m_access2, SIGNAL( finishLoad() ), SLOT( slotFinishLoad() ) );
             m_access2->get();
-            return;
+            return ;
         }
     }
     /* finish loading session & emit signal to the parent object */
@@ -392,19 +408,10 @@ int DatInfo::isLocked()
 
 /* They are public */
 
-const QString& DatInfo::getRawDat()
-{
-    QMutexLocker locker( &m_mutex );
-
-    return m_rawData;
-}
-
 const QString& DatInfo::getDat( int num )
 {
     QMutexLocker locker( &m_mutex );
-
-    if ( num <= 0 || ( int ) m_resDatVec.size() <= num ) return QString::null;
-    if ( ! m_resDatVec[ num ].set ) return QString::null;
+    if ( !parseDat( num ) ) return QString::null;
 
     return m_resDatVec[ num ].linestr;
 }
@@ -417,15 +424,8 @@ const QString& DatInfo::getId( int num )
     return m_resDatVec[ num ].id;
 }
 
-const QString& DatInfo::getBody( int num )
-{
-    QMutexLocker locker( &m_mutex );
-    if ( !parseDat( num ) ) return QString::null;
-
-    return m_resDatVec[ num ].body;
-}
-
-const QString& DatInfo::getName( int num )
+/* plain strings of name */
+QString DatInfo::getPlainName( int num )
 {
     QMutexLocker locker( &m_mutex );
     if ( !parseDat( num ) ) return QString::null;
@@ -433,78 +433,112 @@ const QString& DatInfo::getName( int num )
     return m_resDatVec[ num ].name;
 }
 
-/* plain (parsed) strings of name  */
-QString DatInfo::getPlainName( int num )
-{
-    QMutexLocker locker( &m_mutex );
-    if ( !parseDat( num ) ) return QString::null;
 
-    return m_resDatVec[ num ].parsedName;
-}
-
-
-/* plain (parsed) strings of body  */
-QString DatInfo::getPlainBody( int num )
-{
-    QMutexLocker locker( &m_mutex );
-    if ( !parseDat( num ) ) return QString::null;
-
-    QString bodytext;
-    QString line = m_resDatVec[ num ].body;
-
-    Kita::parseBODYdatText( PARSEMODE_TEXT, line, bodytext );
-
-    return bodytext;
-}
-
-
-/* plain (parsed) strings of title */
+/* plain strings of title */
 QString DatInfo::getPlainTitle( int num )
 {
     QMutexLocker locker( &m_mutex );
     if ( !parseDat( num ) ) return QString::null;
 
-    bool showAddr = KitaConfig::showMailAddress();
-    QString titletext;
-    Kita::parseTITLEdatText( PARSEMODE_TEXT, num, showAddr, m_resDatVec[ num ], titletext );
+    QString titleHTML;
+    Kita::createTitleHTML( m_resDatVec[ num ], titleHTML );
 
-    return titletext;
+    QString retStr;
+    Kita::DatToText( titleHTML, retStr );
+
+    return retStr;
+}
+
+
+/* plain strings of body  */
+QString DatInfo::getPlainBody( int num )
+{
+    QMutexLocker locker( &m_mutex );
+    if ( !parseDat( num ) ) return QString::null;
+
+    QString retStr;
+    Kita::DatToText( m_resDatVec[ num ].bodyHTML, retStr );
+
+    return retStr;
 }
 
 
 /*-----------------------------------------*/
 /* HTML data                               */
 
-/* HTML strings */
-/* Note that this function checks Abone internally. */ /* public */
-QString DatInfo::getHtml( int startnum, int endnum )
+
+/* get HTML strings of title & body.
+ 
+   return values are defined in datinfo.h.  */ /* public */
+
+int DatInfo::getHTML( int num, bool checkAbone, QString& titleHTML, QString& bodyHTML )
 {
     QMutexLocker locker( &m_mutex );
+    return getHTMLPrivate( num, checkAbone, titleHTML, bodyHTML );
+}
 
-    QString retstr = QString::null;
-    bool showAddr = KitaConfig::showMailAddress();
+/* private */
+int DatInfo::getHTMLPrivate( int num, bool checkAbone, QString& titleHTML, QString& bodyHTML )
+{
+    if ( !parseDat( num ) ) return KITA_HTML_NOTPARSED;
 
-    for ( int num = startnum; num <= endnum; num++ ) {
+    bool abone = checkAbone & checkAbonePrivate( num );
+    RESDAT& resdat = m_resDatVec[ num ];
 
-        if ( !parseDat( num ) ) continue;
-        if ( checkAbonePrivate( num ) ) retstr += aboneHTML( num );
-        else if ( m_resDatVec[ num ].broken ) retstr += brokenHTML( num );
-        else retstr += Kita::ResDatToHtml( m_resDatVec[ num ], num, showAddr );
+    if ( !resdat.broken && !abone ) {
+
+        createTitleHTML( resdat, titleHTML );
+        bodyHTML = resdat.bodyHTML;
+    } else {
+
+        /* "abone" */
+        if ( abone ) {
+            titleHTML = QString().setNum( num ) + " " + i18n( "Abone" );
+            bodyHTML = "<a href=\"#abone" + QString().setNum( num ) + "\">";
+            bodyHTML += i18n( "Abone" ) + "</a>";
+
+            return KITA_HTML_ABONE;
+        }
+
+        /* "broken" */
+        else {
+            titleHTML = QString().setNum( num ) + " " + i18n( "Broken" );
+            bodyHTML = i18n( "Broken" );
+
+            return KITA_HTML_BROKEN;
+        }
     }
 
-    return retstr;
+    return KITA_HTML_NORMAL;
 }
 
 
-/* return HTML strings that have ID = strid. */
-/* Note that this function checks Abone internally. */ /* public */
+/* get HTML strings from startnum to endnum.
+ 
+   return value is HTML strings               */  /* public */
+QString DatInfo::getHTMLString( int startnum, int endnum, bool checkAbone )
+{
+    QMutexLocker locker( &m_mutex );
+
+    QString retHTML = QString::null;
+
+    for ( int num = startnum; num <= endnum; num++ ) {
+
+        QString html;
+        getHTMLofOneRes( num, checkAbone, html );
+        retHTML += html;
+    }
+
+    return retHTML;
+}
+
+
+/* return HTML strings that have ID = strid. */ /* public */
 QString DatInfo::getHtmlByID( const QString& strid, int &count )
 {
     QMutexLocker locker( &m_mutex );
 
-    QString retstr = QString::null;
-    bool showAddr = KitaConfig::showMailAddress();
-
+    QString retHTML = QString::null;
     count = 0;
 
     for ( int i = 1; i <= m_thread->readNum(); i++ ) {
@@ -513,43 +547,30 @@ QString DatInfo::getHtmlByID( const QString& strid, int &count )
 
         if ( m_resDatVec[ i ].id == strid ) {
             count ++;
-            if ( checkAbonePrivate( i ) ) retstr += aboneHTML( i );
-            else if ( m_resDatVec[ i ].broken ) retstr += brokenHTML( i );
-            else retstr += Kita::ResDatToHtml( m_resDatVec[ i ], i, showAddr );
+
+            QString html;
+            getHTMLofOneRes( i, TRUE, html );
+            retHTML += html;
         }
     }
 
-    return retstr;
+    return retHTML;
 }
 
 
 /* private */
-QString DatInfo::aboneHTML( int num )
+void DatInfo::getHTMLofOneRes( int num, bool checkAbone, QString& html )
 {
+    html = QString::null;
+    QString titleHTML, bodyHTML;
+    if ( getHTMLPrivate( num, checkAbone, titleHTML, bodyHTML ) == KITA_HTML_NOTPARSED ) return ;
 
-    QString tmpstr = QString( "<dl><dt>" );
-    tmpstr += QString().setNum( num ) + " " + Kita::utf8ToUnicode( KITAUTF8_ABONE );
-    tmpstr += "</dt><dd>";
-    tmpstr += Kita::utf8ToUnicode( KITAUTF8_ABONE );;
-    tmpstr += "<br/><br/></dd></dl>";
-
-    return tmpstr;
+    if ( m_resDatVec[ num ].isResponsed ) titleHTML.replace( "<a href=\"#write", "<a class=\"coloredLink\" href=\"#write" );
+    html += "<div class=\"pop_res_title\">" + titleHTML + "</div>";
+    html += "<div class=\"pop_res_body\">" + bodyHTML + "</div>";
 }
 
 
-/* private */
-QString DatInfo::brokenHTML( int num )
-{
-
-    QString tmpstr = QString( "<dl><dt>" );
-    tmpstr += QString().setNum( num ) + " " + Kita::utf8ToUnicode( KITAUTF8_NAME );
-    tmpstr += "</dt><dd>";
-    tmpstr += Kita::utf8ToUnicode( KITAUTF8_KOWARE );;
-    tmpstr += "<br/><br/></dd></dl>";
-
-    return tmpstr;
-}
-
 
 /*-------------------------------*/
 /* Get HTML document of res tree.*/
@@ -589,7 +610,7 @@ QString DatInfo::getTreeByResReverse( const int rootnum, int& count )
 /* private */
 QString DatInfo::getTreeByResPrivate(
     const int rootnum,
-    bool reverse,   /* reverse search */
+    bool reverse,    /* reverse search */
     int& count )
 {
 
@@ -604,7 +625,7 @@ QString DatInfo::getTreeByResPrivate(
 /* private */
 QString DatInfo::getTreeByResCore(
     const int rootnum,
-    bool reverse,   /* reverse search */
+    bool reverse,    /* reverse search */
     int& count, QString prestr )
 {
     if ( !parseDat( rootnum ) ) return QString::null;
@@ -627,7 +648,6 @@ QString DatInfo::getTreeByResCore(
 
     } else { /* collect responses for which rootnum has anchors */
 
-        setAncList( rootnum );
         AncList& anclist = m_resDatVec[ rootnum ].anclist;
         for ( AncList::iterator it = anclist.begin(); it != anclist.end(); ++it ) {
             for ( int i = ( *it ).from; i <= QMIN( rootnum - 1, ( *it ).to ) ; i++ ) {
@@ -671,13 +691,12 @@ QString DatInfo::getTreeByResCore(
 bool DatInfo::checkRes( const int num, const int target )
 {
     const int range = 20;
-    if ( ! parseDat( num ) ) return FALSE;
+    if ( !parseDat( num ) ) return FALSE;
 
-    setAncList( num );
     AncList& anclist = m_resDatVec[ num ].anclist;
 
     for ( AncList::iterator it = anclist.begin(); it != anclist.end(); ++it ) {
-        if( ( *it ).to - ( *it ).from > range ) continue;
+        if ( ( *it ).to - ( *it ).from > range ) continue;
         if ( target >= ( *it ).from && target <= ( *it ).to ) return TRUE;
     }
 
@@ -686,196 +705,6 @@ bool DatInfo::checkRes( const int num, const int target )
 }
 
 
-/*--------------------------*/
-/* set AncList              */ /* private */
-
-/* This function sets anchor list.
-   For example, a res has anchors >>2-3 and >>4, then
-   
-   anclist[0].from = 2,
-   anclist[0].to = 3,
-   anclist[1].from = 4,
-   anclist[1].to = 4.   
-*/
-void DatInfo::setAncList( int num )
-{
-
-    if ( ! parseDat( num ) ) return ;
-    if ( m_resDatVec[ num ].setAnclist ) return ;
-
-    m_resDatVec[ num ].setAnclist = TRUE;
-
-    QString linkstr;
-    int refNum[ 2 ];
-    unsigned int pos;
-    ANCNUM anctmp;
-
-    AncList& anclist = m_resDatVec[ num ].anclist;
-    anclist.clear();
-
-    QString line = m_resDatVec[ num ].body;
-
-    /* remove HTML tags */
-    line.replace( "<br>", "\n" );
-    QRegExp rex( "<[^>]*>" );
-    line.remove( rex );
-
-    const QChar *chpt = line.unicode();
-    unsigned int i;
-    unsigned int length = line.length();
-
-    /* parse body */
-    for ( i = 0 ; i < length ; i++ ) {
-
-        if ( chpt[ i ].unicode() == UTF16_BRACKET ||  /* > */
-                ( chpt[ i ] == '&' && chpt[ i + 1 ] == 'g' && chpt[ i + 2 ] == 't' && chpt[ i + 3 ] == ';' )  /* "&gt;" */
-           ) {
-            while ( Kita::parseResAnchor( chpt + i, length - i, linkstr, refNum, pos ) ) {
-                if ( refNum[ 1 ] < refNum[ 0 ] ) refNum[ 1 ] = refNum[ 0 ];
-                anctmp.from = refNum[ 0 ];
-                anctmp.to = refNum[ 1 ];
-                anclist += anctmp;
-                i += pos;
-            }
-
-            i += ( pos - 1 );
-        }
-    }
-
-    /* parse name */
-    line = m_resDatVec[ num ].name;
-    chpt = line.unicode();
-    i = 0;
-    length = line.length();
-
-    while ( Kita::parseResAnchor( chpt + i, length - i, linkstr, refNum, pos ) ) {
-        if ( refNum[ 1 ] < refNum[ 0 ] ) refNum[ 1 ] = refNum[ 0 ];
-        anctmp.from = refNum[ 0 ];
-        anctmp.to = refNum[ 1 ];
-        anclist += anctmp;
-        i += pos;
-    }
-}
-
-
-
-/*----------------------------------*/
-/*  Get DOM element                 */
-
-/* This function returns the element
-   of DOM.
- 
-   This function checks Abone
-   internally. So, if the res is
-   aboned,the output is "abone" node.
-   
-   If the res is broken, the output
-   is "broken" node.
-                                    */ 
-/* public */
-bool DatInfo::getDomElement(
-
-    /* input */
-    int num,
-    DOM::HTMLDocument& hdoc,  /* root of HTML document */
-
-    /* output */
-    DOM::Element& retelm )
-{
-
-    QMutexLocker locker( &m_mutex );
-    if ( !parseDat( num ) ) return FALSE;
-
-    QString tmpstr;
-    QString status = "normal";
-    DOM::Element bodynode, titlenode, tmpelm;
-    DOM::HTMLTableElement table;
-    bool showAddr = KitaConfig::showMailAddress();
-    bool showAA = KitaConfig::showAA();
-    bool abone = checkAbonePrivate( num );
-
-    RESDAT& resdat = m_resDatVec[ num ];
-
-    if ( !resdat.broken && !abone ) {
-
-        /* title node */
-        table = hdoc.createElement( "TABLE" );
-        titlenode = table;
-        tmpelm = table.insertRow( 0 );
-        Kita::parseTITLEdat( PARSEMODE_DOM, hdoc, num, showAddr, resdat, tmpelm, tmpstr );
-
-        /* body node */
-        bodynode = hdoc.createElement( "DIV" );
-        {
-            /* put the span node at the head of each line */
-            if ( showAA ) {
-
-                tmpelm = bodynode.appendChild( hdoc.createElement( "SPAN" ) );
-                {
-                    tmpelm.setAttribute( "style", "color: white" );
-                    tmpelm.appendChild( hdoc.createTextNode( "" ) );
-                }
-            }
-
-            Kita::parseBODYdat( PARSEMODE_DOM, resdat.body, hdoc, showAA, bodynode, tmpstr );
-        }
-
-    } else { /* abone or data is broken */
-
-        QString namestr;
-        QString bodystr;
-
-        if ( abone ) { /* "abone" node */
-            namestr = Kita::utf8ToUnicode( KITAUTF8_ABONE );
-            bodystr = Kita::utf8ToUnicode( KITAUTF8_ABONE );
-            status = "abone";
-        } else { /* "broken" node */
-            namestr = Kita::utf8ToUnicode( KITAUTF8_NAME );
-            bodystr = Kita::utf8ToUnicode( KITAUTF8_KOWARE );
-            status = "broken";
-        }
-
-        /* title node */
-        table = hdoc.createElement( "TABLE" );
-        titlenode = table;
-        tmpelm = table.insertRow( 0 );
-        tmpelm = tmpelm.appendChild( hdoc.createElement( "TD" ) );
-        tmpelm.appendChild( hdoc.createTextNode(
-                                QString().setNum( num ) + " " + namestr ) );
-
-        /* body node */
-        bodynode = hdoc.createElement( "DIV" );
-        tmpelm = bodynode.appendChild( hdoc.createElement( "SPAN" ) );
-        {
-            tmpelm.setAttribute( "style", "color: red" );
-            tmpelm.appendChild( hdoc.createTextNode( bodystr ) );
-        }
-
-    }
-
-
-    /*-----------------------------*/
-
-    retelm = hdoc.createElement( "DIV" );
-    retelm.setAttribute( "class", "res_block" );
-    {
-        retelm.setAttribute( "kita_type", "res" );
-        retelm.setAttribute( "kita_status", status );
-        retelm.setAttribute( "id", QString().setNum( num ) );
-        retelm.setAttribute( "kita_rname", resdat.name );
-        retelm.setAttribute( "kita_rid", resdat.id );
-
-        titlenode.setAttribute( "class", "res_title" );
-        bodynode.setAttribute( "class", "res_body" );
-        retelm.appendChild( titlenode );
-        retelm.appendChild( bodynode );
-    }
-
-    return TRUE;
-}
-
-
-
 /*-----------------------*/
 /* several information */
 
@@ -921,8 +750,16 @@ int DatInfo::getNumByID( const QString& strid )
 int DatInfo::getDatSize()
 {
     QMutexLocker locker( &m_mutex );
+    if ( m_access == NULL ) return 0;
 
-    return m_rawData.length();
+    return m_access->dataSize();
+}
+
+
+/* public */
+const bool DatInfo::isResponsed( int num ) const
+{
+    return m_resDatVec[ num ].isResponsed;
 }
 
 
@@ -939,7 +776,18 @@ bool DatInfo::isBroken()
 {
     QMutexLocker locker( &m_mutex );
 
-    return m_broken;
+    if ( m_broken ) return m_broken;
+
+    if ( m_access == NULL ) return FALSE;
+
+    int rescode = m_access->responseCode();
+    bool invalid = m_access->invalidDataReceived();
+
+    /* see also Access::slotReceiveThreadData() */
+    if ( invalid && ( rescode == 200 || rescode == 206 ) ) return TRUE;
+
+    /* maybe "Dat Ochi" */
+    return FALSE;
 }
 
 /* public */
@@ -964,7 +812,7 @@ bool DatInfo::checkID( const QString& strid, int num )
 
 
 /* Are keywords included ? */ /* public */
-bool DatInfo::checkWord( QStringList& stlist,  /* list of keywords */
+bool DatInfo::checkWord( QStringList& stlist,   /* list of keywords */
                          int num,
                          bool checkOR /* AND or OR search */
                        )
@@ -972,7 +820,7 @@ bool DatInfo::checkWord( QStringList& stlist,  /* list of keywords */
     QMutexLocker locker( &m_mutex );
     if ( !parseDat( num ) ) return FALSE;
 
-    QString str_text = m_resDatVec[ num ].body;
+    QString str_text = m_resDatVec[ num ].bodyHTML;
 
     for ( QStringList::iterator it = stlist.begin(); it != stlist.end(); ++it ) {
 
@@ -993,24 +841,6 @@ bool DatInfo::checkWord( QStringList& stlist,  /* list of keywords */
     return TRUE;
 }
 
-/* public */
-bool DatInfo::isMarked( int num )
-{
-    QMutexLocker locker( &m_mutex );
-
-    return m_resDatVec[ num ].marked;
-}
-
-
-/* public */
-void DatInfo::setMark( int num, bool mark )
-{
-    QMutexLocker locker( &m_mutex );
-
-    m_resDatVec[ num ].marked = mark;
-}
-
-
 
 
 /*--------------------------------*/
@@ -1038,7 +868,7 @@ void DatInfo::resetAbonePrivate()
     m_aboneByID = ( !KitaConfig::aboneIDList().empty() );
     m_aboneByName = ( !KitaConfig::aboneNameList().empty() );
     m_aboneByBody = ( !KitaConfig::aboneWordList().empty() );
-    m_aboneByRes = m_aboneByID | m_aboneByName | m_aboneByBody;
+    m_aboneChain = ( m_aboneByID | m_aboneByName | m_aboneByBody ) & KitaConfig::aboneChain() ;
 }
 
 
@@ -1067,14 +897,13 @@ bool DatInfo::checkAbonePrivate( int num )
         checktmp = checkAboneCore( m_resDatVec[ num ].id, KitaConfig::aboneIDList() );
 
     if ( !checktmp && m_aboneByName )
-        checktmp = checkAboneCore( m_resDatVec[ num ].parsedName, KitaConfig::aboneNameList() );
+        checktmp = checkAboneCore( m_resDatVec[ num ].name, KitaConfig::aboneNameList() );
 
     if ( !checktmp && m_aboneByBody )
-        checktmp = checkAboneCore( m_resDatVec[ num ].body, KitaConfig::aboneWordList() );
+        checktmp = checkAboneCore( m_resDatVec[ num ].bodyHTML, KitaConfig::aboneWordList() );
 
-    if ( !checktmp && m_aboneByRes ) {
-        setAncList( num );
-        AncList& anclist = m_resDatVec[ num ].anclist;
+    if ( !checktmp && m_aboneChain ) {
+        AncList & anclist = m_resDatVec[ num ].anclist;
 
         for ( AncList::iterator it = anclist.begin();
                 it != anclist.end() && !checktmp ; ++it ) {
@@ -1120,30 +949,19 @@ bool DatInfo::checkAboneCore( const QString& str, QStringList& strlist )
 
 
 
-/*---------------------------------------*/
-/* simple parsing function               */
-
-/* This function parses struct RESDAT by
-   Kita::parseResDat. In short, this
-   splits the raw date into name, id,
-   date, and bodytext, etc.
- 
-   Note that this function keeps data as
-   the raw data. So, you need to parse them
-   later by getPlainBody, getHtml,
-   getDomElement, etc. 
-                                         */ /* private */
+/* parsing function for ResDat */
+/* This function parses the raw data by Kita::parseResDat() */ /* private */
 bool DatInfo::parseDat( int num )
 {
-
-    if ( num <= 0 || ( int ) m_resDatVec.size() <= num ) return FALSE;
+    if ( num <= 0 || m_thread->readNum() < num ) return FALSE;
     if ( m_resDatVec[ num ].parsed ) return TRUE;
 
+    //   qDebug("parseDat %d",num);
+
     QString subject = QString::null;
-    if ( !Kita::parseResDat( m_resDatVec[ num ], subject ) ) return FALSE;
-    if ( subject != QString::null && num == 1 ) {
-        m_thread->setThreadName( subject );
-    }
+    Kita::parseResDat( m_resDatVec[ num ], subject );
+    if ( num == 1 && subject != QString::null ) m_thread->setThreadName( subject );
+    if ( m_resDatVec[ num ].broken ) m_broken = TRUE;
 
     return TRUE;
 }
