@@ -23,20 +23,21 @@ namespace Kita
     class ParseMisc
     {
     public:
-	static KURL parseURL( const KURL& url , QString& refstr ){
-	    return Kita::getDatURL( url , refstr ); }
+        static KURL parseURL( const KURL& url , QString& refstr )
+        {
+            return Kita::getDatURL( url , refstr );
+        }
 
-	static KURL parseURLonly( const KURL& url ){ return Kita::getDatURL( url ); }
-	
-	static QString qcpToUnicode( const QString& str ){ return Kita::qcpToUnicode( str ); }
-	
-	static QString utf8ToUnicode( const QString& str ){ return Kita::utf8ToUnicode( str ); }
-	
-	static QString DatToHtml( const QString& rawData, int num, bool showAddr ){
-	    return Kita::DatToHtml( rawData, num, showAddr ); }
+        static KURL parseURLonly( const KURL& url ) { return Kita::getDatURL( url ); }
 
-	static int stringToPositiveNum( const QChar *cdat, const unsigned int length ){
-	    return Kita::stringToPositiveNum( cdat, length ); }
+        static QString qcpToUnicode( const QString& str ) { return Kita::qcpToUnicode( str ); }
+
+        static QString utf8ToUnicode( const QString& str ) { return Kita::utf8ToUnicode( str ); }
+
+        static int stringToPositiveNum( const QChar *cdat, const unsigned int length )
+        {
+            return Kita::stringToPositiveNum( cdat, length );
+        }
     };
 
 }
