@@ -13,6 +13,7 @@
 
 #include <kurl.h>
 #include <qdict.h>
+#include <qvaluelist.h>
 
 namespace Kita
 {
@@ -25,34 +26,40 @@ namespace Kita
 
         KURL m_datURL;
         QString m_threadName;
-	int m_resNum;
-	int m_readNum;
-	int m_viewPos;
-	bool m_isOpened;
+        int m_resNum;
+        int m_readNum;
+        int m_viewPos;
+        bool m_isOpened;
+        QValueList< int > m_markList;
 
     public:
         Thread( const KURL& datURL );
         ~Thread();
 
         const KURL& datURL() const;
-	
+
         const QString& threadName() const;
-	void setThreadName( QString threadName );
+        void setThreadName( QString threadName );
 
-	const int resNum() const;
-	void setResNum( int num );
+        const int resNum() const;
+        void setResNum( int num );
 
-	const int readNum() const;
-	void setReadNum( int num );
-	
-	const int viewPos() const;
-	void setViewPos( int viewPos );
+        const int readNum() const;
+        void setReadNum( int num );
+
+        const int viewPos() const;
+        void setViewPos( int viewPos );
+
+        bool isOpened() const;
+        void setIsOpened( bool isOpend );
+
+        const QValueList< int >& markList() const;
+        void setMarkList( const QValueList< int >& markList );
+        bool isMarked( int num );
+        bool setMark( int num, bool newStatus );
+
+        /*----------------------*/
 
-	bool isOpened() const;
-	void setIsOpened( bool isOpend );
-	
-	/*----------------------*/
-	
         static Thread* getByURL( const KURL& datURL );
         static Thread* getByURLNew( const KURL& datURL );
         static void replace( const QString& fromURL, const QString& toURL );
