@@ -50,12 +50,13 @@ private:
     Kita::UIPrefPage* m_uiPage;
     Kita::AbonePrefPage* m_abonePage;
     Kita::LoginPrefPage* m_loginPage;
-//    DebugPrefPage* m_debugPage;
+    //    DebugPrefPage* m_debugPage;
 
 private slots:
     void slotChanged();
     virtual void slotOk();
     virtual void slotDefault();
+    void slotAboutToShowPage( QWidget* page );
 
 signals:
     void fontChanged( const QFont& );
@@ -80,6 +81,7 @@ namespace Kita
     public:
         AsciiArtPrefPage( QWidget* parent = 0 );
     public slots:
+        void init();
         void apply();
         void reset();
 
