@@ -40,8 +40,7 @@ KitaThreadTabWidget::KitaThreadTabWidget( int mode, QWidget* parent, const char*
     m_mode = mode;
 
     switch ( m_mode ) {
-    case TABMODE_THREADVIEW: setXMLFile( "kitathreadtabwidgetui.rc" ); break;
-    case TABMODE_KITANAVI: setXMLFile( "kitanaviui.rc" ); break;
+    case TABMODE_THREADVIEW: setXMLFile( "threadtabwidgetui.rc" ); break;
     }
 
     setTabBar( new KitaThreadTabBar( this ) );
